==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/common/zastupuzivateleformular.php <==
<?php
/**
 * stanislav.elbl, 03.11.2017
 * Formular pro vkladani a editaci zastupu uzivatele
 */

namespace RonPortal\Common;

use Ron\Controls\FormField;
use Ron\DB\DBRecord;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RCOsobyFormField;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Controls\UserLoginFormField;
use RonPortal\Controls\UserRCFormField;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalDBRecord;
use RonPortal\User;
use RonPortal\ZastupyController;


class ZastupUzivateleFormular extends RonPortalForm
{
    /** @var FormField[]    Asociativni pole formularovych poli pro jednotlive role */
    private $fieldRole = [];

    /**
     * @param \Ron\DB\Database $database
     * @param string $formAction
     * @param bool $vlastni     Priznak, jestli se jedna o vlastni zastup nebo zastup jineho uzivatele
     * @throws NeniPravoException
     * @throws \Exception
     */
    function __construct($database, $vlastni, $formAction = 'new')
    {
        parent::__construct($database, $formAction);

        $this ->code = 'formzastupuzivatele';

        if (!Prava::vratPrava('zast_uz_komu') ->jsouNejakePrava()) {
            throw new NeniPravoException();
        }

        if ($vlastni  &&  !Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC(User::getRC())) {
            throw new NeniPravoException();
        }

        $this -> stornoAction = '?menuid=zastupuzivatele';

        $this -> title = TextManager::_('Zadost_o_zastup_uzivatele');
        $this -> sqlTableName = 'ZastupUzivatele';
        $this ->sqlSelectPart = 'Id, PlatnostOd, PlatnostDo, Zastupujici, Zastupovany, Poznamka';

        $this ->setXmlEventsName('ZASTUP_UZIVATELE');

        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('Id') ->setPrimary(true) ->setSqlFieldIndex(0)
            ->setCode('field-id');

        if ($vlastni) {
            $this->addField( new UserRCFormField('Zastupovany') )
                ->setReadOnly(true) ->setSqlFieldIndex(4)
                ->setCode('field-zastupovany');
        } else {
            $this ->addField(FormField::FIELD_TYPE_HIDDEN)
                ->setFieldName('cizi_zastup') ->setSqlFieldName(null) ->setDefaultValue('1');

            $this ->addField( new RCOsobyFormField('zast_uz_komu', time()))
                ->setFieldName('Zastupovany') ->setSqlFieldName('Zastupovany') ->setSqlFieldIndex(4)
                ->setCaption('Zastupovany')
                ->setCode('field-zastupovany');
        }

        $this -> addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('PlatnostOd') ->setSqlFieldIndex(1) ->setRequired(true)
            ->setCode('field-platnostod')
            ->setCaption('Platnost_od') //FORM_FIELD_DEFAULT_VALUE => StringUtils::format('date',DateUtils::today()),
            ->setFieldId('Zastup_PlatnostOd')
            ->setOtherHtmlParams('data-roncalendar-next="PlatnostDo"' . ($this ->formAction == 'new' ? ' data-roncalendar-mindate="' . date('j.n.Y', time()) . '"' : ''));

        $this -> addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('PlatnostDo') ->setSqlFieldIndex(2)
            ->setCode('field-platnostdo')
            ->setCaption('Platnost_do') //FORM_FIELD_DEFAULT_VALUE => StringUtils::format('date',DateUtils::today()),
            ->setFieldId('Zastup_PlatnostDo')
            ->setOtherHtmlParams('data-roncalendar-prev="PlatnostOd"' . ($this ->formAction == 'new' ? ' data-roncalendar-mindate="' . date('j.n.Y', time()) . '"' : ''));

        // doplni zaskrtavatka pro role
        $seznamRoli = $this ->nactiRole($this ->isInsert() ? null : (int)$_GET['record']);
        foreach ($seznamRoli as $row) {
            $this ->fieldRole[$row[0]] = $this ->addField(FormField::FIELD_TYPE_CHECK)
                ->setFieldName('*role_' . StringUtils::htmlTextConvert($row[0]))
                ->setCode('field-role-' . StringUtils::htmlTextConvert($row[0]))
                ->setCaption2(StringUtils::htmlTextConvert($row[1]))
                ->setDefaultValue((bool)$row[2]);
        }

        // vyber zastupujiciho uzivatele
//        $this ->addField( new OsobaField(TextManager::_('Zastupujici'), 'zast_uz_koho', time(), true))
//            ->setFieldName('Zastupujici'); // edit=true ? (pozor! pro false to asi nebude fungovat!)

        $this ->addField( new RCOsobyFormField('zast_uz_koho', time()))
            ->setFieldName('Zastupujici')
            ->setSqlFieldName('Zastupujici') ->setSqlFieldIndex(3)
            ->setCaption('Zastupujici')
            ->setCode('field-zastupujici')
            ->setDefaultValue('');


        // Poznamka (vzkaz)
        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setSqlFieldIndex(5)
            ->setCode('field-poznamka')
            ->setCaption('Poznamka');

        //$this -> addField( new UserRCField('RCOdesilatele') );
        $this->addField(new UserLoginFormField(true, 'Insert_UserName'))
            ->setCode('field-insert_username');

        $this->addField(FormField::FIELD_TYPE_ACTUAL_TIME)
            ->setFieldName('Insert_Timestamp')
            ->setCode('field-insert_timestamp')
            ->setReadOnly(true);

        $this->addField(new UserLoginFormField(false, 'Update_UserName'))
            ->setCode('field-update_username')
            ->setUpdateLog(true);

        $this->addField(FormField::FIELD_TYPE_ACTUAL_TIME)
            ->setFieldName('Update_Timestamp')
            ->setCode('field-update_timestamp')
            ->setUpdateLog(true);
    }


    function loadRecord()
    {
        $result = parent::loadRecord();

        $prava = Prava::vratPrava('zast_uz_komu');
        if (!$prava ->lzeZobrazitRC($result[4])) {
            // aktualniho uzivatel nema pravo na editaci zaznamu
            throw new NeniPravoException();
        }
        return $result;
    }


    function nactiRole($idZaznamu = null)
    {
        $result = [];

        // doplni zaskrtavatka pro role
        if ( !isset($idZaznamu) ) {
            // pri vkladani jen seznam existujicich roli
            $cursor = $this ->database->getSqlResult(
                'SELECT Kod, Popis, 0 FROM RoleProZastupUzivatele WHERE Aktivni = 1');
        } else {
            $params = $this ->database->createParameters();
            $sql =
                'SELECT Kod, Popis, VybraneRoleProZastup.IdZastupu' .
                ' FROM RoleProZastupUzivatele INNER JOIN ZastupUzivatele' .
                '   ON 1 = 1' .
                ' LEFT OUTER JOIN VybraneRoleProZastup' .
                '   ON VybraneRoleProZastup.KodRole = RoleProZastupUzivatele.Kod' .
                '   AND VybraneRoleProZastup.IdZastupu = ZastupUzivatele.Id' . // $params ->addParameter($_GET['record']) . - nefunguje v ODBC
                ' WHERE RoleProZastupUzivatele.Aktivni = 1' .
                ' AND ZastupUzivatele.Id = ' . $params ->addParameter((int)$idZaznamu);

            $cursor = $this ->database->getSqlResult($sql, $params);
        }

        while ($row = $cursor ->fetch()) {
            $result[] = $row;
        }

        if ( !isset($idZaznamu) ) {
            if (count($result) == 1) {
                $result[0][2] = 1; // jen jedna role => defaultne zap
            }
        }

        return $result;
    }


    function createDBRecordFields($rec, $insert)
    {
        if (isset($_POST['cizi_zastup']) && (int)$_POST['cizi_zastup']) {
            $zastupovany = PracovniPomer::nactiPP($this ->database, $_POST['Zastupovany']);

            if (!Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC($zastupovany ->rc)) {
                throw new \Exception('Pro nastaveni zastupu vybrane osoby nemate pravo!');
            }

            $rec ->addField('Zastupovany', '', false, 15, $zastupovany ->rc);
            $rec ->addField('', '', false, 0, '   ' . $zastupovany ->jmenoPrijmeni);
        }


        $pp = PracovniPomer::nactiPP($this ->database, $_POST['Zastupujici']);

        if (!Prava::vratPrava('zast_uz_koho') ->lzeZobrazitRC($pp ->rc)) {
            throw new \Exception('Pro pozadani vybrane osoby o zastup nemate pravo!');
        }

        parent::createDBRecordFields($rec, $insert);

        $rec ->addField('', '', false, 0, '(Zastupujici: ' . $pp ->jmenoPrijmeni . ')');
        $rec ->addField('ZaznamAktivity', 'memo', true);
    }


    function nactiVybraneRole()
    {
        $result = [];

        $seznamRoli = $this ->nactiRole(null);
        foreach ($seznamRoli as $row) {
            if (isset($_POST['role_' . $row[0]])  &&  $_POST['role_' . $row[0]]) {
                $result[] = $row[0];
            }
        }

        return $result;
    }



    function zkontrolujRole()
    {
        $vybraneRole = $this ->nactiVybraneRole();
        if (!$vybraneRole) throw new \Exception(TextManager::_('Neni_vybrana_role_pro_zastup'));
    }


    function checkRequiredFields($edit)
    {
        if (!parent::checkRequiredFields($edit)) return false;
        $this ->zkontrolujRole();
        return true;
    }


    /**
     * @param DBRecord $rec
     * @return bool
     */
    function beforeUpdateRecord($rec)
    {
        $result = parent::beforeUpdateRecord($rec);

        $logStr = '';
        $fieldOd = $rec ->findFieldByName('PlatnostOd');
        $fieldDo = $rec ->findFieldByName('PlatnostDo');
        if ($fieldOd ->value != $fieldOd ->originalValue  ||  $fieldDo ->value != $fieldDo ->originalValue) {
            $logStr .= TextManager::_('log_zmena_platnosti_zaznamu');
            $field = $rec ->findFieldByName('ZaznamAktivity');

            $field ->setNewValue($field ->originalValue . ZastupyController::getActivityLogText($logStr));
        }


        return $result;
    }


    /**
     * @param DBRecord $rec
     * @return bool
     * @throws \Exception
     */
    function afterInsertRecord($rec)
    {
        $seznamRoli = $this ->nactiVybraneRole();

        // doplni vybrane role
        foreach ($seznamRoli as $role) {
            $vybraneRoleRec = new RonPortalDBRecord($this ->database, 'VybraneRoleProZastup');
            $vybraneRoleRec ->addField('IdZastupu', 'int', false, 0, $rec['Id']);
            $vybraneRoleRec ->addField('KodRole', 'string', false, 10, $role);
            $vybraneRoleRec ->insertRecord();
        }

        return parent::afterInsertRecord($rec);
    }


    /**
     * @param DBRecord $rec
     * @return bool
     */
    function afterUpdateRecord($rec)
    {
        $seznamRoli = $this ->nactiRole($rec['Id']);

        foreach ($seznamRoli as $row) {
            $field = $this ->fieldRole[$row[0]];

            if ($field  &&  $field ->visible  &&  !$field ->readOnly) {
                $delete = false;
                $insert = false;
                if ($row[2] && !$_POST['role_' . $row[0]]) {
                    // role se musi smazat
                    $delete = true;
                } else if (!$row[2] && $_POST['role_' . $row[0]]) {
                    // role se musi zapsat
                    $insert = true;
                }

                if ($delete || $insert) {
                    $vybraneRoleRec = new RonPortalDBRecord($this->database, 'VybraneRoleProZastup');
                    $vybraneRoleRec->addField('IdZastupu', 'int', false, 0, $rec['Id']);
                    $vybraneRoleRec->addField('KodRole', 'string', false, 10, $row[0]);
                    $vybraneRoleRec->addField('', '', false, 0, date('j.n.Y', $rec['PlatnostOd']) . ' - ' . ($rec['PlatnostDo'] ? date('j.n.Y', $rec['PlatnostDo']) : '(neukonceno)'));
                    $vybraneRoleRec->addField('', '', false, 0, 'Zastupovany: ' . $rec['Zastupovany']);
                    $vybraneRoleRec->addField('', '', false, 0, 'Zastupujici: ' . $rec['Zastupujici']);

                    if ($insert) {
                        $vybraneRoleRec->insertRecord();
                    } else if ($delete) {
                        $params = $this->database->createParameters();
                        $filter = 'IdZastupu = ' . $params->addParameter($rec['Id']) . ' AND KodRole = ' . $params->addParameter($row[0]);
                        $vybraneRoleRec->setWhere($filter, $params);
                        if ($vybraneRoleRec->loadRecord()) {
                            $vybraneRoleRec->deleteRecord();
                        }
                    }
                }
            }
        }

        return parent::afterUpdateRecord($rec);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/common/zastupuzivateleformular.php <==
<?php
/**
 * stanislav.elbl, 03.11.2017
 * Formular pro vkladani a editaci zastupu uzivatele
 */

namespace RonPortal\Common;

use Ron\Controls\FormField;
use Ron\DB\DBRecord;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RCOsobyFormField;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Controls\UserLoginFormField;
use RonPortal\Controls\UserRCFormField;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalDBRecord;
use RonPortal\User;
use RonPortal\ZastupyController;


class ZastupUzivateleFormular extends RonPortalForm
{
    /** @var FormField[]    Asociativni pole formularovych poli pro jednotlive role */
    private $fieldRole = [];

    /**
     * @param \Ron\DB\Database $database
     * @param string $formAction
     * @param bool $vlastni     Priznak, jestli se jedna o vlastni zastup nebo zastup jineho uzivatele
     * @throws NeniPravoException
     * @throws \Exception
     */
    function __construct($database, $vlastni, $formAction = 'new')
    {
        parent::__construct($database, $formAction);

        $this ->code = 'formzastupuzivatele';

        if (!Prava::vratPrava('zast_uz_komu') ->jsouNejakePrava()) {
            throw new NeniPravoException();
        }

        if ($vlastni  &&  !Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC(User::getRC())) {
            throw new NeniPravoException();
        }

        $this -> stornoAction = '?menuid=zastupuzivatele';

        $this -> title = TextManager::_('Zadost_o_zastup_uzivatele');
        $this -> sqlTableName = 'ZastupUzivatele';
        $this ->sqlSelectPart = 'Id, PlatnostOd, PlatnostDo, Zastupujici, Zastupovany, Poznamka';

        $this ->setXmlEventsName('ZASTUP_UZIVATELE');

        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('Id') ->setPrimary(true) ->setSqlFieldIndex(0)
            ->setCode('field-id');

        if (!$this ->isInsert()) {
            $this ->addField( new RCOsobyFormField('zast_uz_komu', time())) ->setReadOnly(true)
                ->setFieldName('Zastupovany') ->setSqlFieldName('Zastupovany') ->setSqlFieldIndex(4)
                ->setCaption('Zastupovany')
                ->setCode('field-zastupovany');
        } else if ($vlastni) {
            $this->addField( new UserRCFormField('Zastupovany') )
                ->setReadOnly(true) ->setSqlFieldIndex(4)
                ->setCode('field-zastupovany');
        } else {
            $this ->addField(FormField::FIELD_TYPE_HIDDEN)
                ->setFieldName('cizi_zastup') ->setSqlFieldName(null) ->setDefaultValue('1');

            $this ->addField( new RCOsobyFormField('zast_uz_komu', time()))
                ->setFieldName('Zastupovany') ->setSqlFieldName('Zastupovany') ->setSqlFieldIndex(4)
                ->setCaption('Zastupovany')
                ->setCode('field-zastupovany');
        }

        $this -> addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('PlatnostOd') ->setSqlFieldIndex(1) ->setRequired(true)
            ->setCode('field-platnostod')
            ->setCaption('Platnost_od') //FORM_FIELD_DEFAULT_VALUE => StringUtils::format('date',DateUtils::today()),
            ->setFieldId('Zastup_PlatnostOd')
            ->setOtherHtmlParams('data-roncalendar-next="PlatnostDo"' . ($this ->formAction == 'new' ? ' data-roncalendar-mindate="' . date('j.n.Y', time()) . '"' : ''));

        $this -> addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('PlatnostDo') ->setSqlFieldIndex(2)
            ->setCode('field-platnostdo')
            ->setCaption('Platnost_do') //FORM_FIELD_DEFAULT_VALUE => StringUtils::format('date',DateUtils::today()),
            ->setFieldId('Zastup_PlatnostDo')
            ->setOtherHtmlParams('data-roncalendar-prev="PlatnostOd"' . ($this ->formAction == 'new' ? ' data-roncalendar-mindate="' . date('j.n.Y', time()) . '"' : ''));

        // doplni zaskrtavatka pro role
        $seznamRoli = $this ->nactiRole($this ->isInsert() ? null : (int)$_GET['record']);
        foreach ($seznamRoli as $row) {
            $this ->fieldRole[$row[0]] = $this ->addField(FormField::FIELD_TYPE_CHECK)
                ->setFieldName('*role_' . StringUtils::htmlTextConvert($row[0]))
                ->setCode('field-role-' . StringUtils::htmlTextConvert($row[0]))
                ->setCaption2(StringUtils::htmlTextConvert($row[1]))
                ->setDefaultValue((bool)$row[2]);
        }

        // vyber zastupujiciho uzivatele
//        $this ->addField( new OsobaField(TextManager::_('Zastupujici'), 'zast_uz_koho', time(), true))
//            ->setFieldName('Zastupujici'); // edit=true ? (pozor! pro false to asi nebude fungovat!)

        $this ->addField( new RCOsobyFormField('zast_uz_koho', time()))
            ->setFieldName('Zastupujici')
            ->setSqlFieldName('Zastupujici') ->setSqlFieldIndex(3)
            ->setCaption('Zastupujici')
            ->setCode('field-zastupujici')
            ->setDefaultValue('');


        // Poznamka (vzkaz)
        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setSqlFieldIndex(5)
            ->setCode('field-poznamka')
            ->setCaption('Poznamka');

        //$this -> addField( new UserRCField('RCOdesilatele') );
        $this->addField(new UserLoginFormField(true, 'Insert_UserName'))
            ->setCode('field-insert_username');

        $this->addField(FormField::FIELD_TYPE_ACTUAL_TIME)
            ->setFieldName('Insert_Timestamp')
            ->setCode('field-insert_timestamp')
            ->setReadOnly(true);

        $this->addField(new UserLoginFormField(false, 'Update_UserName'))
            ->setCode('field-update_username')
            ->setUpdateLog(true);

        $this->addField(FormField::FIELD_TYPE_ACTUAL_TIME)
            ->setFieldName('Update_Timestamp')
            ->setCode('field-update_timestamp')
            ->setUpdateLog(true);
    }


    function loadRecord()
    {
        $result = parent::loadRecord();

        $prava = Prava::vratPrava('zast_uz_komu');
        if (!$prava ->lzeZobrazitRC($result[4])) {
            // aktualniho uzivatel nema pravo na editaci zaznamu
            throw new NeniPravoException();
        }
        return $result;
    }


    function nactiRole($idZaznamu = null)
    {
        $result = [];

        // doplni zaskrtavatka pro role
        if ( !isset($idZaznamu) ) {
            // pri vkladani jen seznam existujicich roli
            $cursor = $this ->database->getSqlResult(
                'SELECT Kod, Popis, 0 FROM RoleProZastupUzivatele WHERE Aktivni = 1');
        } else {
            $params = $this ->database->createParameters();
            $sql =
                'SELECT Kod, Popis, VybraneRoleProZastup.IdZastupu' .
                ' FROM RoleProZastupUzivatele INNER JOIN ZastupUzivatele' .
                '   ON 1 = 1' .
                ' LEFT OUTER JOIN VybraneRoleProZastup' .
                '   ON VybraneRoleProZastup.KodRole = RoleProZastupUzivatele.Kod' .
                '   AND VybraneRoleProZastup.IdZastupu = ZastupUzivatele.Id' . // $params ->addParameter($_GET['record']) . - nefunguje v ODBC
                ' WHERE RoleProZastupUzivatele.Aktivni = 1' .
                ' AND ZastupUzivatele.Id = ' . $params ->addParameter((int)$idZaznamu);

            $cursor = $this ->database->getSqlResult($sql, $params);
        }

        while ($row = $cursor ->fetch()) {
            $result[] = $row;
        }

        if ( !isset($idZaznamu) ) {
            if (count($result) == 1) {
                $result[0][2] = 1; // jen jedna role => defaultne zap
            }
        }

        return $result;
    }


    function createDBRecordFields($rec, $insert)
    {
        $pp = PracovniPomer::nactiPP($this ->database, $_POST['Zastupujici']);

        if (!Prava::vratPrava('zast_uz_koho') ->lzeZobrazitRC($pp ->rc)) {
            throw new \Exception('Pro pozadani vybrane osoby o zastup nemate pravo!');
        }

        parent::createDBRecordFields($rec, $insert);

        if (isset($_POST['cizi_zastup']) && (int)$_POST['cizi_zastup']) {
            $zastupovany = PracovniPomer::nactiPP($this ->database, $_POST['Zastupovany']);

            if (!Prava::vratPrava('zast_uz_komu') ->lzeZobrazitRC($zastupovany ->rc)) {
                throw new \Exception('Pro nastaveni zastupu vybrane osoby nemate pravo!');
            }

            // $rec ->addField('Zastupovany', '', false, 15, $zastupovany ->rc);
            $rec ->addField('', '', false, 0, '  (Zastupovany: ' . $zastupovany ->jmenoPrijmeni . ')');
        }

        $rec ->addField('', '', false, 0, '  (Zastupujici: ' . $pp ->jmenoPrijmeni . ')');
        $rec ->addField('ZaznamAktivity', 'memo', true);
    }


    function nactiVybraneRole()
    {
        $result = [];

        $seznamRoli = $this ->nactiRole(null);
        foreach ($seznamRoli as $row) {
            if (isset($_POST['role_' . $row[0]])  &&  $_POST['role_' . $row[0]]) {
                $result[] = $row[0];
            }
        }

        return $result;
    }



    function zkontrolujRole()
    {
        $vybraneRole = $this ->nactiVybraneRole();
        if (!$vybraneRole) throw new \Exception(TextManager::_('Neni_vybrana_role_pro_zastup'));
    }


    function checkRequiredFields($edit)
    {
        if (!parent::checkRequiredFields($edit)) return false;
        $this ->zkontrolujRole();
        return true;
    }


    /**
     * @param DBRecord $rec
     * @return bool
     */
    function beforeUpdateRecord($rec)
    {
        $result = parent::beforeUpdateRecord($rec);

        $logStr = '';
        $fieldOd = $rec ->findFieldByName('PlatnostOd');
        $fieldDo = $rec ->findFieldByName('PlatnostDo');
        if ($fieldOd ->value != $fieldOd ->originalValue  ||  $fieldDo ->value != $fieldDo ->originalValue) {
            $logStr .= TextManager::_('log_zmena_platnosti_zaznamu');
            $field = $rec ->findFieldByName('ZaznamAktivity');

            $field ->setNewValue($field ->originalValue . ZastupyController::getActivityLogText($logStr));
        }


        return $result;
    }


    /**
     * @param DBRecord $rec
     * @return bool
     * @throws \Exception
     */
    function afterInsertRecord($rec)
    {
        $seznamRoli = $this ->nactiVybraneRole();

        // doplni vybrane role
        foreach ($seznamRoli as $role) {
            $vybraneRoleRec = new RonPortalDBRecord($this ->database, 'VybraneRoleProZastup');
            $vybraneRoleRec ->addField('IdZastupu', 'int', false, 0, $rec['Id']);
            $vybraneRoleRec ->addField('KodRole', 'string', false, 10, $role);
            $vybraneRoleRec ->insertRecord();
        }

        return parent::afterInsertRecord($rec);
    }


    /**
     * @param DBRecord $rec
     * @return bool
     */
    function afterUpdateRecord($rec)
    {
        $seznamRoli = $this ->nactiRole($rec['Id']);

        foreach ($seznamRoli as $row) {
            $field = $this ->fieldRole[$row[0]];

            if ($field  &&  $field ->visible  &&  !$field ->readOnly) {
                $delete = false;
                $insert = false;
                if ($row[2] && !($_POST['role_' . $row[0]] ?? null)) {
                    // role se musi smazat
                    $delete = true;
                } else if (!$row[2] && ($_POST['role_' . $row[0]] ?? null)) {
                    // role se musi zapsat
                    $insert = true;
                }

                if ($delete || $insert) {
                    $vybraneRoleRec = new RonPortalDBRecord($this->database, 'VybraneRoleProZastup');
                    $vybraneRoleRec->addField('IdZastupu', 'int', false, 0, $rec['Id']);
                    $vybraneRoleRec->addField('KodRole', 'string', false, 10, $row[0]);
                    $vybraneRoleRec->addField('', '', false, 0, date('j.n.Y', $rec['PlatnostOd']) . ' - ' . ($rec['PlatnostDo'] ? date('j.n.Y', $rec['PlatnostDo']) : '(neukonceno)'));
                    $vybraneRoleRec->addField('', '', false, 0, 'Zastupovany: ' . $rec['Zastupovany']);
                    $vybraneRoleRec->addField('', '', false, 0, 'Zastupujici: ' . $rec['Zastupujici']);

                    if ($insert) {
                        $vybraneRoleRec->insertRecord();
                    } else if ($delete) {
                        $params = $this->database->createParameters();
                        $filter = 'IdZastupu = ' . $params->addParameter($rec['Id']) . ' AND KodRole = ' . $params->addParameter($row[0]);
                        $vybraneRoleRec->setWhere($filter, $params);
                        if ($vybraneRoleRec->loadRecord()) {
                            $vybraneRoleRec->deleteRecord();
                        }
                    }
                }
            }
        }

        return parent::afterUpdateRecord($rec);
    }
}
